==> haskell-gnuidn-0.2.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
key: gnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
license: GPL-3
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
abi: 0a5f93bfbef4035a507703770e6e0849
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
extra-libraries:
    idn idn
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnuidn-0.2.2-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-3RFo3Ld9bqM7vNFSsnvsa4
key: gnuidn-0.2.2-3RFo3Ld9bqM7vNFSsnvsa4
license: GPL-3
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
abi: 3610b7845b0954bc505546e36c022c41
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-3RFo3Ld9bqM7vNFSsnvsa4
extra-libraries:
    idn idn
depends:
    base-4.10.1.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
